### Glyph Display

#### Zooming

There are many ways to zoom in and out of Edit View.
With a trackpad, zoom using pinch and stretch gestures.
Or hold down the Option key and use a scroll gesture or the scroll wheel of a mouse.
Or activate the Zoom tool  (shortcut Z) and click on the canvas to zoom in, Option-click to zoom out.
Alternatively, click and drag across an area, and it will be zoomed to fill the window.

Tip:

The Spotlight shortcut in the System Settings may need to be changed for the Cmd-Space shortcut to work in Glyphs.

Temporarily activate the Zoom tool by holding down Cmd-Space for zooming in or Cmd-Opt-Space for zooming out.
If Cmd-Space collides with another shortcut, try pressing Space before adding the Command key.

Or use the zoom commands from the “View” menu:
“Zoom In” (Cmd-Plus) and “Zoom Out” (Cmd-Minus).
“Zoom to Active Layer” (Cmd-Zero) will maximize the area between ascender and descender in the window.
“Zoom to Actual Size” (Cmd-Opt-Zero) will zoom one font unit to the size of one screen point.
(One screen point is one pixel on a classic low-resolution screen and two pixels on new high-resolution Retina screens.)

Or use the zoom minus / plus buttons in the bottom-right corner of the window.
Alternatively, set the zoom value numerically by entering a point height in the field between the buttons.
The zoom value is the number of display points at which 1000 font units are shown.
The size of a display point depends on the physical display that the Mac uses.
Display points are independent of pixels, so one point might correspond to one pixel on a low-resolution display or two pixels on a high-resolution display.
For example, at a zoom value of 300, a 1000 font units long path would be displayed at 300 display points, and a path of length 500 font units would be displayed at 150 display points.

#### Panning

On a trackpad, drag two fingers to pan around Edit View.
Scroll on a mouse to pan vertically, hold down Shift to scroll horizontally.
Or, drag the scroll bars on the right and bottom edges of the displayed canvas.

Tip:

The Spotlight shortcut in the System Settings may need to be changed for the Cmd-Space shortcut to work in Glyphs.

Alternatively, switch to the Hand tool  (shortcut H) and drag the canvas around, or simply hold down the Space bar to temporarily switch to the Hand tool.
When in text mode, pressing the Space bar would add a space to the text.
Press Cmd-Space and subsequently release the Command key to avoid inserting a space.

#### View Options

Toggle settings that influence the glyph display in Edit View from the “View” menu:

“Show Nodes”

displays the on-curve and off-curve points of a glyph.
Control the display of points on the foreground layer, the background layer, and Extra Nodes.

“Show Metrics”

shows the vertical and horizontal metrics as well as the alignment zones of the glyph.

“Show Metric Names”

adds labels to the metrics in Edit View.

“Show Hints”

displays PostScript hints.
Use the TrueType Instructor tool for TrueType hints.

“Show Anchors”

shows the anchors of the current glyph.

“Show Info”

displays the Info box as well as contextual controls at the bottom of the Palette.

“Show Background”

displays the paths and components of the background layer as outlines in the foreground layer.

“Show Image”

shows images placed on a glyph layer.

“Show Guides”

displays local and global guides.

“Show Measurement Line”

shows horizontal and vertical measurement lines with numbers for the amount of space between the glyphs.
Only visible when the Text tool is active.

“Show Annotations”

shows annotations placed with the Annotation tool.

“Show Bounding Box”

displays the bounding box of a selection with transformation knobs on all four sides and corners.

“Fill Preview”

fills closed paths with the foreground color.
The current glyph is not filled unless the Text, Hand, or Zoom tool is selected.
The foreground color can be changed in the settings.
See Appearance for details.

Many third-party reporter plug-ins are available for changing or enhancing the glyph display in Edit View.
After they are installed, they will also show up in the “View” menu.

#### Glyph & Layer Colors

Label colors can be set both glyph-wide and layer-specific from the context menu.
Control-click or right-click anywhere on the canvas of an active glyph and pick the color from the context menu.

Hold down Option and choose “Set Layer Color” to pick a layer color rather than a glyph color.
Both glyph and layer colors will be displayed in the Info box (“View” → “Show Info”, Cmd-Shift-I):

The glyph color is displayed on the left half, the layer color on the right half, which corresponds to the display of label colors in Font View.
See Color Label for managing color labels in Font View.